@@ -28,7 +28,7 @@ local runDebugger = dofile "run_debugger"
 -- Increment each time a savegame break would occur
 -- and add compatibility code in afterLoad functions
 
-local SAVEGAME_VERSION = 117
+local SAVEGAME_VERSION = 122
 
 class "App"
 
@@ -58,11 +58,12 @@ function App:App()
     window_resize = self.onWindowResize,
     music_over = self.onMusicOver,
     movie_over = self.onMovieOver,
-    sound_over = self.onSoundOver
+    sound_over = self.onSoundOver,
+    multigesture = self.onMultiGesture
   }
   self.strings = {}
   self.savegame_version = SAVEGAME_VERSION
-  self.check_for_updates = true
+  self.check_for_updates = false
 end
 
 --! Starts a Lua DBGp client & connects it to a DBGp server.
@@ -152,6 +153,8 @@ function App:init()
   self.video:setBlueFilterActive(false)
   SDL.wm.setIconWin32()
 
+  self.video:setCaptureMouse(self.config.capture_mouse)
+
   local caption_descs = {self.video:getRendererDetails()}
   if compile_opts.jit then
     caption_descs[#caption_descs + 1] = compile_opts.jit
@@ -1093,6 +1096,10 @@ function App:onSoundOver(...)
   return self.audio:onSoundPlayed(...)
 end
 
+function App:onMultiGesture(...)
+  return self.ui:onMultiGesture(...)
+end
+
 function App:checkInstallFolder()
   self.fs = FileSystem()
   local status, _
@@ -1284,8 +1291,10 @@ end
 -- a specific savegame verion is from.
 function App:getVersion(version)
   local ver = version or self.savegame_version
-  if ver > 111 then
+  if ver > 122 then
     return "Trunk"
+  elseif ver > 111 then
+    return "v0.61"
   elseif ver > 105 then
     return "v0.60"
   elseif ver > 91 then
